Installation
============


Installing picea can be done through pip

.. code-block:: shell

    pip install picea


Or from the github page

.. code-block:: shell

    git clone https://holmrenser.github.com/picea
    cd picea
    python setup.py install